=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2005-10-26 05:49:06 +0000
+++ bzrlib/errors.py	2005-10-26 06:20:15 +0000
@@ -275,7 +275,39 @@
         BzrError.__init__(self, "Stores for branch %s are not listable" % br)
 
 
-from bzrlib.weave import WeaveError, WeaveParentMismatch
+class WeaveError(BzrNewError):
+    """Error in processing weave: %(message)s"""
+    def __init__(self, message=None):
+        BzrNewError.__init__(self)
+        self.message = message
+
+
+class WeaveRevisionAlreadyPresent(WeaveError):
+    """Revision {%(revision_id)s} already present in %(weave)s"""
+    def __init__(self, revision_id, weave):
+        WeaveError.__init__(self)
+        self.revision_id = revision_id
+        self.weave = weave
+
+
+class WeaveRevisionNotPresent(WeaveError):
+    """Revision {%(revision_id)s} not present in %(weave)s"""
+    def __init__(self, revision_id, weave):
+        WeaveError.__init__(self)
+        self.revision_id = revision_id
+        self.weave = weave
+
+
+class WeaveFormatError(WeaveError):
+    """Weave invariant violated: %(what)s"""
+    def __init__(self, what):
+        WeaveError.__init__(self)
+        self.what = what
+
+
+class WeaveParentMismatch(WeaveError):
+    """Parents are mismatched between two revisions."""
+    
 
 class TransportError(BzrError):
     """All errors thrown by Transport implementations should derive

=== modified file 'bzrlib/selftest/testreweave.py'
--- bzrlib/selftest/testreweave.py	2005-10-25 05:04:30 +0000
+++ bzrlib/selftest/testreweave.py	2005-10-26 06:20:15 +0000
@@ -100,7 +100,8 @@
         knows about revisions the destination does not.  In 
         this test the second weave knows of an additional parent of 
         v2.  Any revisions which are in common still have to have the 
-        same text."""
+        same text.
+        """
         w1 = self.build_weave1()
         wa = w1.copy()
         wb = Weave()

=== modified file 'bzrlib/weave.py'
--- bzrlib/weave.py	2005-10-25 05:04:30 +0000
+++ bzrlib/weave.py	2005-10-26 06:20:15 +0000
@@ -71,19 +71,9 @@
 from difflib import SequenceMatcher
 
 from bzrlib.trace import mutter
-
-
-class WeaveError(Exception):
-    """Exception in processing weave"""
-
-
-class WeaveFormatError(WeaveError):
-    """Weave invariant violated"""
-
-
-class WeaveParentMismatch(WeaveError):
-    """Parents are mismatched between two revisions."""
-    
+from bzrlib.errors import WeaveError, WeaveFormatError, WeaveParentMismatch, \
+        WeaveRevisionNotPresent, WeaveRevisionAlreadyPresent
+
 
 class Weave(object):
     """weave - versioned text file storage.
@@ -224,8 +214,7 @@
         try:
             return self._name_map[name]
         except KeyError:
-            raise WeaveError("name %r not present in weave %r" %
-                             (name, self._weave_name))
+            raise WeaveRevisionNotPresent(name, self)
 
     def names(self):
         return self._names[:]
@@ -243,12 +232,9 @@
         If it is, return the (old) index; otherwise raise an exception.
         """
         idx = self.lookup(name)
-        if sorted(self._parents[idx]) != sorted(parents):
-            raise WeaveError("name \"%s\" already present in weave "
-                             "with different parents" % name)
-        if sha1 != self._sha1s[idx]:
-            raise WeaveError("name \"%s\" already present in weave "
-                             "with different text" % name)            
+        if sorted(self._parents[idx]) != sorted(parents) \
+            or sha1 != self._sha1s[idx]:
+            raise WeaveRevisionAlreadyPresent(name, self)
         return idx
         
     def add(self, name, parents, text, sha1=None):
@@ -484,8 +470,7 @@
                 elif c == ']':
                     dset.remove(v)
                 else:
-                    raise WeaveFormatError('unexpected instruction %r'
-                                           % v)
+                    raise WeaveFormatError('unexpected instruction %r' % v)
             else:
                 assert isinstance(l, basestring)
                 assert istack
@@ -545,16 +530,13 @@
                 if isactive:
                     result.append((istack[-1], lineno, l))
             lineno += 1
-
         if istack:
-            raise WFE("unclosed insertion blocks at end of weave",
-                                   istack)
+            raise WeaveFormatError("unclosed insertion blocks "
+                    "at end of weave: %s" % istack)
         if dset:
-            raise WFE("unclosed deletion blocks at end of weave",
-                                   dset)
-
+            raise WeaveFormatError("unclosed deletion blocks at end of weave: %s"
+                                   % dset)
         return result
-    
 
 
     def get_iter(self, name_or_index):

